@@ -1,12 +1,12 @@
 import io
 import logging
-import struct
 
 from bitstring import BitArray
 from PIL import Image
 
 from ..core.assetbuilder import AssetBuilder
 from ..core.palette import Colour, Palette, type_palette
+from ..core.struct import struct_blit_image
 
 
 class ImageAsset(AssetBuilder):
@@ -71,30 +71,17 @@ class ImageAsset(AssetBuilder):
     def to_binary(self, input_data):
         image = self.quantize_image(input_data)
 
-        # TODO Image format needs rewriting to support more than 255 palette entries, this is a bug!
-        # This fix allows `test_image_png_cli_strict_palette_pal` to pass.
-        self.palette.entries = self.palette.entries[:255]
-
-        palette_data = self.palette.tobytes()
-
         if self.packed:
             bit_length = self.palette.bit_length()
             image_data = BitArray().join(BitArray(uint=x, length=bit_length) for x in image.tobytes()).tobytes()
         else:
             image_data = image.tobytes()
 
-        palette_size = struct.pack('<B', len(self.palette))
-
-        payload_size = struct.pack('<H', len(image_data))
-        image_size = struct.pack('<HH', *image.size)
-
-        data = bytes('SPRITEPK' if self.packed else 'SPRITERW', encoding='utf-8')
-        data += payload_size
-        data += image_size
-        data += bytes([0x10, 0x00, 0x10, 0x00])  # Rows/cols deprecated
-        data += b'\x02'                          # Pixel format
-        data += palette_size
-        data += palette_data
-        data += image_data
-
-        return data
+        return struct_blit_image.build({
+            'type': 'PK' if self.packed else 'RW',
+            'width': image.size[0],
+            'height': image.size[1],
+            'palette_entries': len(self.palette),
+            'palette': self.palette.tostruct(),
+            'data': image_data
+        })
